// -------------------------------------------------------------------
//      File name:     G4PEEffectFluoModelTest
//
//      Author:        Maria Grazia Pia
// 
//      Creation date: 1 August 2013
//
//      Modifications: 
//
// -------------------------------------------------------------------

#include "globals.hh"
//#include "G4ios.hh"
#include "G4PEEffectFluoModel.hh"
#include "G4ParticleDefinition.hh"
#include "G4Gamma.hh"
#include "G4NistElementBuilder.hh"
#include "G4SystemOfUnits.hh"

int main()
{

  std::cout << "This is a test of the photoelectric cross section of the Geant4 Standard photoelectric model" 
	    << std::endl;
				    
  // Define a set of energies at which cross sections are calculated
  std::vector<double> energyGrid;

  energyGrid.push_back(0.0001);
  energyGrid.push_back(0.001);
  energyGrid.push_back(0.01);
  energyGrid.push_back(0.1);
  energyGrid.push_back(1.);
  energyGrid.push_back(10.);
  energyGrid.push_back(100.);
  energyGrid.push_back(1000.);
  energyGrid.push_back(10000.);
  energyGrid.push_back(100000.);			
  
  int nEnergies = energyGrid.size();
 
  // Geant4 standard photoelectric model: its cross section is to be tested
  G4PEEffectFluoModel* model = new G4PEEffectFluoModel;
  
  // Instantiate a photon (as a ParticleDefinition)
  G4ParticleDefinition* photon = G4Gamma::GammaDefinition();

  // Instantiate an element builder, which can instantiate any element of which we want to calculate 
  // the photoelectric cross section(what is the argument of the constructor?)
  G4NistElementBuilder elementBuilder(1);
 
  // These are useless dummy variables needed by  G4PEEffectFluoModel::ComputeCrossSectionPerAtom as arguments
  double a = 0.;
  double b = 0.;

  // Calculate cross sections at predefined energies for each element of the periodic table (Z from 1 to 100)
  for (int Z=1; Z<100; Z++)
    {
      for (int i=0; i<nEnergies; i++)
	{
	  double e = energyGrid[i];

	  // Here there is a confusion of responsibilities: why is G4NistElementBuilder responsible for returning
	  // the A corresponding to a Z, while this is also a responsibility of G4Element?
	  double A = elementBuilder.GetAtomicMassAmu(Z);
	  double z(Z);

	  std::cout << "Calculate photoelectric cross section for Z = " << Z << std::endl;

	  // Why does one have to pass A as an argument? The photoelectric cross section does not depend on A!
	  // What are a and b? ComputeCrossSectionPerAtom does not use them
	  // Note: although one has to pass a photon definition as an argument, the ComputeCrossSectionPerAtom function
	  // does not use it. The calculation would be identical if, instead of passing a photon as an argument,
	  // one would pass a proton or whatever other particle
	  double sigmaStd = model->ComputeCrossSectionPerAtom(photon,e,z,A,a,b) / barn;

	  // Dump the photoelectric cross section for the current element at the current energy
	  std::cout << std::setw(12) << std::setfill(' ') << Z << "\t "
	  	    << std::setw(12) << std::setfill(' ') << e << "\t "
	  	    << std::setw(12) << std::setfill(' ') << sigmaStd  << "\t "
	  	    << std::endl;
	}
    }

  
  delete model;
 
  std::cout << "END OF THE MAIN PROGRAM" << G4endl;
}












